# Berryditos

Berryditos is a tool that can edit and burn Raspbian images.

## Getting Started

### Installing
Berryditos is on PyPI so installing it is easy with *pip*.
``` sudo pip install berryditos ```

### Running
Berryditos is to be run from the console

```berryditos --help```

## License
This project is licensed under the MIT License - see the [LICENSE](https://github.com/tovam/berryditos/blob/master/LICENSE) file for details
